% Euler-Bernoulli Beam-column model for wind and marine turbines
% S Adhikari,
% Started: 16 January 2009
% CONSIDERS SINGLE PARAMETER VARIATIONS: => 2D PLOTS
% PlotCase =1: plots variation against \nu
% PlotCase =2: plots variation against \eta_r
% Both plots are drwan for some particular values of \eta_t which acts as
% the global loop
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all; close all;
fsize=14; fname='times';
global nu eta_r eta_t alpha_p beta_p fct0 

PlotCase=2

% Main parameters
 E=2.1e11;
 rho=7800;
 L=81;
 D=3.5;
 t=0.075;
 M=130000; J=0.0;
 [nu_example(1),alpha_p_example(1),beta_p,fct0_example(1),I_example(1),m_example(1),P_example(1),r_example(1),mu_example(1),A_example(1)]=nd_parameters(E,rho,L,D,t,M,J); 
 omega_example(1)=0.37;  %Passing frequency in Hz
 r_example(1)=sqrt(I_example(1)/A_example(1))
  
if PlotCase == 1
    % plots variation against \nu
    nu_min=0.001;nu_max=1.0;n_nu=150;
    nu_array=nu_min: (nu_max-nu_min)/(n_nu-1): nu_max;

    n_eta=6;
    eta_array=[1 2 5 10 100 500]
    axis_vector=[0 nu_max 0 0.601];

elseif PlotCase == 2
    % plots variation against \eta_r
    n_nu=6;
    nu_array=[0.001 0.03 0.1 0.25 0.5 1]

    eta_min=1.0;eta_max=200.;n_eta=150;
    eta_array=eta_min: (eta_max-eta_min)/(n_eta-1): eta_max;
    axis_vector=[0 eta_max 0 0.601];
    
end

eta_t_array=[1 5 10 100];
ne=length(eta_t_array);

fct0=fct0_example(1);
options = optimset('Display','off');  % Turn off Display 
% only Exitflag= 1 values can be trusted * * * * IMPORTANT * * * 

for kk=1:ne
    eta_t=eta_t_array(kk);
		for ii=1:n_nu
		    nu=nu_array(ii);            % PL^2/EI
		    alpha_p=nu*fct0^2*L/9.8074;
		    for jj=1:n_eta          		 
				eta_r=eta_array(jj);        % nondimensional support stiffness                        
		        x0=ApproxNaturalFrequency;            
		        [x,Fval,exitflag] = fsolve(@FrequencyFunction,x0,options);      
		        omegan_E(ii,jj)=sqrt(x); 
		        omegan_approx(ii,jj)=sqrt(x0); 
		        %disp(['nu=: ' num2str(nu) ', Exitflag= ' int2str(exitflag) ', Fval=' num2str(real(Fval)) ]);        
		    end
		end
    omegan_E_all{kk}=omegan_E;
    omegan_approx_all{kk}=omegan_approx;
end

eval(['save etat_fixed_data_PlotCase' num2str(PlotCase)]);
clear all;
%------------load data ---------
PlotCase=2
eval(['load etat_fixed_data_PlotCase' num2str(PlotCase)]);

for kk=1:ne
    eta_t=eta_t_array(kk);
    plot_data=real(omegan_E_all{kk})*fct0/2/pi;

    if PlotCase == 1
        expr_point1=[nu_example(1) omega_example(1)];    
        figure(kk);clf;hold all;
        plot(nu_array,plot_data(:,1),'-+',...
             nu_array,plot_data(:,2),'-.x',...
             nu_array,plot_data(:,3),'--',...
             nu_array,plot_data(:,4),':',...
             nu_array,plot_data(:,5),'-.',...
             nu_array,plot_data(:,6),'-k',...        
                'linewidth',1.0)
        xlabel('Nondimensional axial force: \nu = PL^2/EI','FontName',fname,'fontsize',fsize);
        ylabel('\omega_1 = \Omega_1 f_0 (Hz)','FontName',fname,'fontsize',fsize);  
        axis(axis_vector);
        plot(expr_point1(1),expr_point1(2),'*r','MarkerSize',10);
        text(expr_point1(1)*1.05,expr_point1(2)*1.1,'real data','FontName',fname,'FontSize',fsize)
        hleg=legend(['\eta_r=',num2str(eta_array(1),'%4.2f')],['\eta_r=',num2str(eta_array(2),'%4.2f')],['\eta_r=',num2str(eta_array(3),'%4.2f')],['\eta_r=',num2str(eta_array(4),'%4.2f')],['\eta_r=',num2str(eta_array(5),'%4.2f')],['\eta_r=',num2str(eta_array(6),'%4.2f')]);  
        set(hleg,'FontName',fname,'FontSize',12,'Box','off','location','best');
        ha=gca;set(ha,'linewidth',1.5,'FontName',fname,'FontSize',fsize,'Box','on');
        eval(['print -depsc figures/omega1_nu_var_etat' num2str(eta_t) '.eps']);
        eval(['print -djpeg100 figures/omega1_nu_var_etat' num2str(eta_t) '.jpeg']);
    
    elseif PlotCase == 2
        figure(kk);clf;hold all;
        plot(eta_array,plot_data(1,:),'-+',...
             eta_array,plot_data(2,:),'-.x',...
             eta_array,plot_data(3,:),'--',...
             eta_array,plot_data(4,:),':',...
             eta_array,plot_data(5,:),'-.',...
             eta_array,plot_data(6,:),'-k',...        
                'linewidth',1.0)
        xlabel('Nondimensional rotational stiffness: \eta_r = k_r L/EI','FontName',fname,'fontsize',fsize);
        ylabel('\omega_1 = \Omega_1 f_0 (Hz)','FontName',fname,'fontsize',fsize);  
        axis(axis_vector);
        plot([0,eta_max],[omega_example(1),omega_example(1)],'--r','linewidth',1.5)
        text(eta_max*0.4,omega_example(1)*1.1,['blade passing frequency: ' num2str(omega_example(1)) 'Hz'],'FontName',fname,'FontSize',fsize,'color','red')
        ha=gca;set(ha,'linewidth',1.5,'FontName',fname,'FontSize',fsize,'Box','on');
        hleg=legend(['\nu=',num2str(nu_array(1),'%5.3f')],['\nu=',num2str(nu_array(2),'%4.2f')],['\nu=',num2str(nu_array(3),'%4.2f')],['\nu=',num2str(nu_array(4),'%4.2f')],['\nu=',num2str(nu_array(5),'%4.2f')],['\nu=',num2str(nu_array(6),'%4.2f')]);  
        set(hleg,'FontName',fname,'FontSize',12,'Box','off','location','best');
        eval(['print -depsc figures/omega1_eta_var_etat' num2str(eta_t) '.eps']);
        eval(['print -djpeg100 figures/omega1_eta_var_etat' num2str(eta_t) '.jpeg']);

    end

end